#ifndef GNUMERIC_STAT_H
#define GNUMERIC_STAT_H

#include <glib.h>
#include <gnome.h>
#include "../../src/gnumeric.h"
#include "../../src/func.h"
#include "../../src/plugin.h"

PluginInitResult init_plugin (CommandContext *context, PluginData *pd);

#endif /* GNUMERIC_STAT_H */
